import {Injectable} from '@nestjs/common';
import {CreateAlpineiqDto} from './dto/create-alpineiq.dto';
import {UpdateAlpineiqDto} from './dto/update-alpineiq.dto';
import axios from 'axios';

@Injectable()
export class AlpineiqService {
    async personaCreateNewContact(dto: CreateAlpineiqDto) {
        const apiUrl = 'https://lab.alpineiq.com/api/v1.1/loyaltyContact/:uid?optionalstore=true';
        const data = {
            firstName: dto.firstName,
            lastName: dto.lastName,
            mobilePhone: dto.mobilePhone,
            email: dto.email,
            disableSMS: false,
            smsoptin: true
        };

        const config = {
            headers: {
                'x-apikey': process.env.ALPINEIQ_API_KEY,
                'Content-Type': 'application/json'
            }
        };

        const uid = process.env.ALPINEIQ_UID;

        try {
            const response = await axios.post(apiUrl.replace(':uid', uid), data, config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            console.log(e);
            return e;
        }
    }

    async personasFindAll() {
        const apiUrl = 'https://lab.alpineiq.com/api/v1.1/piis/:uid';
        const config = {
            headers: {
                'x-apikey': process.env.ALPINEIQ_API_KEY,
                'Content-Type': 'application/json'
            },
            params: {
                sort: 'inserted',
                dir: 'desc'
            }
        };

        const uid = process.env.ALPINEIQ_UID;

        try {
            const response = await axios.get(apiUrl.replace(':uid', uid), config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            console.log(e);
            return e;
        }
    }

    async personaByContactID(contactID: string) {
        const apiUrl = `https://lab.alpineiq.com/api/v1.1/piis/:uid/${contactID}`;

        const config = {
            headers: {
                'x-apikey': process.env.ALPINEIQ_API_KEY,
                'Content-Type': 'application/json'
            }
        };
        const uid = process.env.ALPINEIQ_UID;

        try {
            const response = await axios.get(apiUrl.replace(':uid', uid), config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            console.log(e);
            return e;
        }
    }


    async getLoyaltyStatus(pii: string) {
        const apiUrl = `https://lab.alpineiq.com/api/v2/loyalty/lookup/:pii`;
        const config = {
            headers: {
                'x-apikey': process.env.ALPINEIQ_API_KEY,
                'Content-Type': 'application/json'
            }
        };

        try {
            const response = await axios.get(apiUrl.replace(':pii', pii), config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            console.log(e);
            return e;
        }
    }

    update(id: number, updateAlpineiqDto: UpdateAlpineiqDto) {
        return `This action updates a #${id} alpineiq`;
    }

    remove(id: number) {
        return `This action removes a #${id} alpineiq`;
    }
}
